# elife-cleaner

Clean and transform article submission files into a consistent format

## Requirements

Install `imagemagick-dev` and `ghostscript` in order for `wand` Python module to open PDF files. Also, the imagemagick `policy.xml` file must be configured to allow reading of PDF files.

## License

Licensed under [MIT](https://opensource.org/licenses/mit-license.php).
